breed [nomads nomad] ; agents in the model

nomads-own
[
  livestock
  small-herd
  ;; variables for insurance
  premium
  savings
  insured?
  ;; variables for restocking
  memory
  target-size
]

patches-own
[ ; variables owned by patches
  pasture ; makes patch an accessible pasture
  rain ; rainfall in mm/a
  green-biomass
  green-biomass-over ; green biomass leftover after feeding
  reserve-biomass ; available to cattle if green biomass does not suffice, specified by gr2
  reserve-biomass-over ; reserve biomass leftover after feeding
  reserve-biomass-usable ; part of reserve biomass that is available for feeding
  green-biomass-seasons ; green biomass split into seasons, based on data from Laisamis
  reserve-biomass-seasons
  Rmax ; reserve biomass' limitation
  pasture-type
  rain-threshold
  patch-number ; auxiliary variable
]

globals
[
  ;livestock-growth-rate ; cattle reproduction rate
  ;rue  ; rain use efficiency
  ;green-biomass-mortality  ; mg, fractional mortality of green biomass
  ;lambda ; threshhold of green biomass divided by reserve biomass, potential of how much green biomass may grow from rerserve biomass
  ;w ; w denoting the recovery rate
  ;gr1 ; gr1 static parameter btw 0 & 1, where 0 denotes strong grazing impact
  ;reserve-biomass-mortality ; mr, with values from 0 to 1
  intake ; consumed biomass by cattle per season
  mobility-threshold
  ;Rmax-value ; maximum reserve biomass
  season ; three months long seasons 1-4
  long-rain-season ; Apr - Jun -- season 0
  long-dry-season ; Jul - Sep -- season 1
  short-rain-season ; Oct - Dec -- season 2
  short-dry-season ; Jan - Mar -- season 3
  entire-livestock ; cumulative mean value of livestock
  livestock-sum-list ; list of the total number of animals of each season
  central-reserve-biomass-list ; list of reserve biomass on the central of each season
  mean-remote-reserve-biomass-list ; list of mean reserve biomass of all remote patches for each season
  mean-rain ; current mean rainfall
  ext-input-rain ; list to store rainfall data from input file
  prob-payout
  ; auxiliary variables
  rain-list
  movement-list
  destock-central
  destock-remote
  destock-insurance
  season-count
  nomad-name-list
  patches-ordered
  filename
  filename-agents
  filename-patches
]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; SETUP PROCEDURES ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  ca

  ;random-seed 1 ;only for testing purposes!

  ; initialize parameters
  ;set livestock-growth-rate 0.085 ; including mortality, based on cattle data
  ;set rue 0.002 ; specific rain use efficiency
  ;set green-biomass-mortality 0.3 ; mg
  ;set lambda 2; threshold of G/R
  ;set w 0.8; w
  ;set gr1 0.5; gr1, impacts the recovery of reserve biomass
  ;set Rmax-value 150000 ; maximum reserve biomass per patch (1500 kg/ha * 100 ha patch size)
  ;set reserve-biomass-mortality 0.05; mr
  set intake annual-intake / 4 ; seasonal intake of cattle per year
  set mobility-threshold 5
  ;set rain-std 80 ; standard deviation of the rainfall
  ;set rain-mean 180 ; mean value of the rainfall
  set long-rain-season 0.5
  set short-rain-season 0.35
  set long-dry-season 0.05
  set short-dry-season 0.1
  set season-count 0
  set season 0
  set destock-central 0
  set destock-remote 0
  set destock-insurance 0

  ; determine the probability of an insurance payout
  if insurance [
    ifelse (rainfall-scenario = "random" or rainfall-scenario = "constant")
    [ set prob-payout calc-prob-payout ]
    [ set prob-payout calc-prob-payout-ext-rain ]
  ]

  ; create list of rainfall data (irrelevant in case of an external rainfall scenario)
  set rain-list create-rain-list

  ;; if we're using a rain scenario, we will read in the data here
  if (rainfall-scenario != "random" and rainfall-scenario != "constant") [
    set ext-input-rain list-rainfall
  ]

  setup-biomass

  setup-agents

  create-movement-list ; aux list that stores the sequence in which agents move (needed to ensure reproducibility)

  do-plot

  reset-ticks

  if write-output? [ setup-output-files ]

  ; create aux lists that are needed for some calculations
  create-lists
end


to setup-agents ; create nomads and their initial livestock
  set entire-livestock []
  set-default-shape nomads "person"
  with-local-randomness [
    create-nomads initial-number-nomads
    [
      set size 1.5
      set color white
      setxy 0 0 ; central patch or rather main village
      set livestock 10
      set memory (list livestock livestock livestock)
      set target-size mean [memory] of self
      set savings 0
      set insured? false

      ifelse livestock > mobility-threshold [ set small-herd false ][ set small-herd true ]
    ]
  ]
end


to setup-biomass ; create all included pastures
  with-local-randomness [
    ask n-of initial-number-permanent-patches patches with [ distance patch 0 0 > 5 ]
    [ ; permanent pastures
      set pcolor green
      set pasture true ; only visible patches with biomass are noticed as pastures
      set reserve-biomass 50000
      set Rmax Rmax-value
      set pasture-type "permanent"
      set rain-threshold 0
    ]
  ]

  ask patch 0 0 [ ; create central patch
      set pcolor 13
      ask neighbors [set pcolor 13]
      set pasture true
      set reserve-biomass initial-number-permanent-patches * 50000
      set Rmax initial-number-permanent-patches * Rmax-value
      set green-biomass-seasons (list 0)
      set pasture-type "central"
    ]

  ; assign to each pasture a running number which is used later-on to extract data from rain-list
  ; (ask-command shuffles order of patches, so that each patch is assigned its number randomly)
  with-local-randomness [
    let patch-num-vector n-values (count patches with [pasture = true]) [?]
    ask patches with [pasture = true] [
      set patch-number first patch-num-vector
      set patch-num-vector but-first patch-num-vector
    ]

    ; initialize rainfall
    let current-rain first rain-list
    ask patches with [pasture = true] [
      ifelse (rainfall-scenario = "random" or rainfall-scenario = "constant")
        [ set rain current-rain ]
        [ set rain first ext-input-rain ]
    ]
  ]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; GO PROCEDURE ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  ifelse ( ticks < number-timesteps )
  [
    tick

    with-local-randomness[ ask nomads [set insured? false] ]


    ;; RAINFALL ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    let current-rain item ticks rain-list

    ask patches with [pasture = true]
    [
      ;; check if we're using a rain scenario from a file
      ifelse (rainfall-scenario = "random" or rainfall-scenario = "constant")
      [ set rain current-rain ]
      [ set rain item ( ticks mod length ext-input-rain ) ext-input-rain ]

      set mean-rain mean [rain] of patches with [pasture = true]


      ;; GREEN BIOMASS GROWTH ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

      set green-biomass green-biomass-growth green-biomass-over reserve-biomass rain
      if  green-biomass > lambda * reserve-biomass ; lambda threshold, potential of how much green biomass may grow from rerserve biomass
      [
        set green-biomass  lambda * reserve-biomass
      ]


      ;; SEASONS SETUP ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

      ; calculated green biomass is split into four seasons, based on mean rainfall
      set green-biomass-seasons ( list ( long-rain-season * green-biomass ) ( long-dry-season * green-biomass ) ( short-rain-season * green-biomass)
        ( short-dry-season * green-biomass ))
      ; calculate how much reserve biomass is available for feeding in total, as specified by gr2
      set reserve-biomass-usable gr2 * reserve-biomass
      ; now split up reserve biomass into seasons, analog to green biomass
      set reserve-biomass-seasons ( list ( long-rain-season * reserve-biomass-usable ) ( long-dry-season * reserve-biomass-usable )
        ( short-rain-season * reserve-biomass-usable) ( short-dry-season * reserve-biomass-usable ))
    ]

    ;; RUN OF INDIVIDUAL SEASONS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    set season 0 ; nomads execute move, feed and - if necessary - destock once per season

    while [ season < 4 ]
    [
      ; aux variables needed for "Destocking" plot
      set destock-central 0
      set destock-remote 0
      set destock-insurance 0

      ; update biomass-over
      ask patches with [pasture = true]
      [ ; at the beginning of the season, "everything" is left over
        set green-biomass-over item season green-biomass-seasons
        set reserve-biomass-over item season reserve-biomass-seasons
      ]


      ; REPRODUCTION AND PURCHASING INSURANCE ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

      if season = 0 [
        foreach (sort nomads) [ ; order irrelevant, just for testing purposes
          ask ? [
            ; reproduction
            set livestock reproduce-livestock livestock

            ifelse livestock > mobility-threshold [ set small-herd false ][ set small-herd true ]


            ; purchase insurance
            if (insurance and ticks >= ins-start and small-herd = false) [ purchase-insurance ]

            ifelse livestock > mobility-threshold [ set small-herd false ][ set small-herd true ]
          ]
        ]
      ]


      ;; DESTOCKING ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

      if ( season = 0 or season = 2 ) [ ;= rainy seasons, all agents are on the central patch
        destock-equal-share
      ]


      ;; MOVE and FEED ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

      ; retrieve moving order from the list to ensure reproducibility
      let nomads-sorted item season item ticks movement-list ; for all randomised moving orders

      ; check if sedentary herds have enough fodder on central patch, have them destock in equal shares if need be
      destock-sedentary-agents

      foreach nomads-sorted [
        if ? != nobody [ ; skip dead agents
          ask ? [
            let old-herd-size livestock
            let animals-destocked-by-agent 0

            ifelse small-herd
            [ ; small herds only feed, but stay on central patch
              setxy 0 0
              feed item season green-biomass-seasons item season reserve-biomass-seasons
            ]
            [ ; large herds move and feed
              move
              feed item season green-biomass-seasons item season reserve-biomass-seasons
              if  ( season = 1 or season = 3 ) [ set animals-destocked-by-agent old-herd-size - livestock ]
            ]
            set destock-remote destock-remote + animals-destocked-by-agent ; update destocking-counters
          ]
        ]
      ]

      ; add remaining biomass to next season
      update-biomass-carry-over


      ;; INSURANCE PAYOUT ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

      ; insurance pays out at the end of the short dry season (= end of the year)
      if ( insurance and ticks >= ins-start and season = 3 ) [
        payout-insurance

      ]

      ;; PLOTTING AND UPDATING OF VARIABLE LISTS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

      do-plot

      set season-count season-count + 1

      ; write output to files
      if write-output? [ do-write-output ]

      update-lists

      ; advance to the next season
      set season season + 1

    ] ;end of while-command


    ask nomads [
      if livestock < 0.1 [set livestock 0] ; quasi-extinction threshold to account for artefacts

      update-restocking-target

      if livestock <= 0 [die] ; agents without animals abandon pastoralism and leave the system
    ]

    if count nomads <= 0 [
      do-plot
      stop
    ]

    ;; RESERVE BIOMASS GROWTH ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    ask patches with [ pasture = true] [
      ; update value of reserve-biomass-over = total reserve - what was available for feeding + what was left over from feeding
      set reserve-biomass-over reserve-biomass - reserve-biomass-usable + reserve-biomass-over
      ; now let reserve biomass grow
      set reserve-biomass reserve-biomass-growth reserve-biomass reserve-biomass-over green-biomass-over green-biomass
    ]
  ]
  [
    stop
  ]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; OTHER PROCEDURES ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report draw-rainfall
  let current-rainfall 0

  ; rainfall drawn from lognormal distribution
  if rainfall-scenario = "random" [
    let sigma2 sqrt ( ln ( ( rain-std ^ 2 ) / ( rain-mean ^ 2 ) + 1 ) )
    let mu ln rain-mean - 0.5 * ( sigma2 ^ 2 )

    let x random-normal mu sigma2
    set current-rainfall exp x
  ]

  ; constant rainfall
  if rainfall-scenario = "constant" [
    set current-rainfall rain-mean
  ]

  report current-rainfall
end


to-report create-rain-list
  let rain-list-local []
  with-local-randomness [
      repeat (number-timesteps + 1) [set rain-list-local lput draw-rainfall rain-list-local] ; create list with length of simulation
  ]
  report rain-list-local
end


to-report calc-prob-payout
    let occurence 0
    ;reset random-seed afterwards (so that rainfall pattern is not altered)
    with-local-randomness [
      ;draw many random numbers from rainfall distribution and calculate the number of occurrences that rain is below strike level
      repeat 1000000 [ if draw-rainfall <= strike-level [ set occurence occurence + 1] ]
    ]
    ; report proportion of payouts
    report occurence / 1000000
end

to-report calc-prob-payout-ext-rain
  let ext-input-rainfall list-rainfall ; create list with rainfall data imported from file
  let drought-events filter [? <= strike-level] ext-input-rainfall ; make list that contains only the drought events of external rainfall data
  let drought-prob (length drought-events / length ext-input-rainfall) ; calculate proportion of droughts
  report drought-prob
end


to-report list-rainfall ; calculate parameters of lognormal distribution
  let ext-input-rainfall []
  file-open rainfall-scenario
  while [ not file-at-end? ]
  [
    set ext-input-rainfall lput file-read ext-input-rainfall
  ]
  file-close
  report ext-input-rainfall
end


; Equation 1 Vegetation model Martin et al.
to-report green-biomass-growth [ green-biomass-over-old reserve-biomass-old current-rainfall ]
  let green-biomass-new green-biomass-over-old + current-rainfall * rue * reserve-biomass-old - green-biomass-mortality * green-biomass-over-old
  report green-biomass-new
end


; Equation 2 Vegetation model Martin et al.
to-report reserve-biomass-growth [ reserve-biomass-old reserve-biomass-over-old green-biomass-over-old green-biomass-old ]
  let portion-green-biomass-used ( green-biomass-old - green-biomass-over-old ) / green-biomass-old
  let portion-reserve-biomass-used ( reserve-biomass-old - reserve-biomass-over-old ) / reserve-biomass-old
  let reserve-biomass-new reserve-biomass-old + w * (portion-green-biomass-used * gr1 + (1 - portion-green-biomass-used)) * green-biomass-old *
    (1 - reserve-biomass-old * 1 / Rmax ) - (reserve-biomass-mortality + portion-reserve-biomass-used) * reserve-biomass-old
  report reserve-biomass-new
end


to update-biomass-carry-over
  ask patches with [pasture = true] [
    if season < 3 [
      ; adjust green biomass and reserve biomass for every season
      ; add remaining green biomass and reserve biomass to the next season after every season
      set green-biomass-seasons replace-item ( season + 1 ) green-biomass-seasons (green-biomass-over + item ( season + 1 ) green-biomass-seasons)
      set reserve-biomass-seasons replace-item ( season + 1 ) reserve-biomass-seasons (reserve-biomass-over + item ( season + 1 ) reserve-biomass-seasons)
    ]
  ]
end


to purchase-insurance
  ; calculate insurance premium: all animals up to [max-ins-sum] are insured
  let ins-sum 0

  ifelse (livestock >= max-ins-sum)
    [ ; purchase insurance for maximally allowed number of animals
      set premium prob-payout * max-ins-sum
      set ins-sum max-ins-sum
    ]
    [ ; purchase insurance for entire herd
      set premium prob-payout * livestock
      set ins-sum livestock
    ]

  ; pay insurance premium from savings
  ifelse savings >= premium
    [
      set savings savings - premium
    ]
    [ ;destock if not enough money on bank account
      let premium-rest premium - savings
      let livestock-new livestock - premium-rest

      ; don't buy insurance if it led to falling below mvsh
      if livestock-new <= mobility-threshold [ stop ]

      ifelse livestock-new >= ins-sum
        [ ; if insurance sum does not change due to destocking
          set livestock livestock - premium-rest
          set destock-insurance destock-insurance + premium-rest
          set savings savings + premium-rest - premium
        ]
        [ ; if destocking affects insurance sum
          let livestock-to-be-sold (livestock * prob-payout - savings) / (1 + prob-payout)
          set livestock livestock - livestock-to-be-sold
          set destock-insurance destock-insurance + livestock-to-be-sold
          set premium prob-payout * livestock
          set savings savings + livestock-to-be-sold - premium
          set savings precision savings 8
        ]
    ]

  set insured? true
end


to payout-insurance
  foreach (sort nomads) [
    if ? != nobody [ ; skip dead agents

      ask ? [
        ; insurance pays out if rainfall is too sparse
        if (insured? and [rain] of patch 0 0 < strike-level) [

          set savings savings + premium / prob-payout

          ; how much livestock can be bought
          let money-avail premium / prob-payout
          ; determine how much livestock needs to be bought
          let livestock-needed target-size - livestock
          if target-size < livestock [set livestock-needed 0] ; if herd is already bigger than target, then do not destock any further

          ifelse (livestock-needed < money-avail)
          [ ; restock to target-size, if enough money available
            set livestock livestock + livestock-needed
            set savings savings - livestock-needed
          ]
          [ ; restock as far as possible
            set livestock livestock + money-avail
            set savings savings - money-avail
          ]
        ]

        ifelse livestock > mobility-threshold [ set small-herd false ][ set small-herd true ]

        ; herds below mobility threshold immediately restock to threshold (if money available)
        if small-herd [
          ; determine how much livestock needs to be bought
          let livestock-needed mobility-threshold - livestock
          ; how much livestock can be bought
          let money-avail savings

          ifelse livestock-needed < money-avail
          [ ; restock to mobility threshold, if enough money available
            set livestock livestock + livestock-needed
            set savings savings - livestock-needed
          ]
          [ ; restock as far as possible
            set livestock livestock + money-avail
            set savings savings - money-avail
          ]
        ]
      ]
    ]
  ]
end


to update-restocking-target
  set memory fput livestock memory
  set memory but-last memory
  set target-size mean [memory] of self
end


; all agents will destock the same percentage of livestock so that all agents fit on the central patch
to destock-equal-share
  with-local-randomness [
    ; determine how much biomass is available on the central patch
    let biomass-available-on-central-patch [ item season green-biomass-seasons + item season reserve-biomass-seasons ] of patch 0 0
    ; determine the number of livestock of all nomads
    let sum-livestock sum [ livestock ] of nomads
    let sum-livestock-old sum-livestock

    ; check whether destocking is necessary
    ; calculate how much percent every nomad needs to destock, based on available biomass, intake and livestock sum,
    ; so that all nomads fit onto the central patch
    let destock-percentage 1
    if sum-livestock > 0 [ set destock-percentage min ( list ( precision (( biomass-available-on-central-patch / intake ) / sum-livestock) 8 ) 1 )]

    ; if destock-percentage equal to one, no destocking is needed
    if destock-percentage < 1 [
      let small-herd-sum sum [livestock] of nomads with [small-herd = true] ; sum up animals of small herds
      let biomass-available-for-large-herds biomass-available-on-central-patch - small-herd-sum * intake ; deduct biomass needed for small herds
      set sum-livestock sum-livestock - small-herd-sum

      if any? nomads with [small-herd = false]
      [
        ; if there are large herds that can destock sufficiently
        set destock-percentage min ( list (( biomass-available-for-large-herds / intake ) / sum-livestock ) 1 )

        ; aux variable that contains the set of nomads that would fall below mobility threshold due to destocking (= "endangered nomads")
        ; (consider only those that would fall *below* 5 animals (i.e. 4 or less) - those destocking to 5 animals would do that also in the "normal" destocking procedure,
        ;  and including them would only decrease the destock-percentage for big-herds)
        let endangered-nomads nomads with [small-herd = false and destock-percentage * livestock < mobility-threshold]

        while [any? endangered-nomads]
        [
          ; if an agent falls below mobility threshold due to destocking, they destock to that threshold but not more
          let destocking-endangered-nomads 0 ; aux variable that sums up the number of animals that endangered-nomads destock

          ask endangered-nomads [
            let amount-to-destock livestock - mobility-threshold
            set livestock livestock - amount-to-destock
            if livestock <= mobility-threshold [ set small-herd true ]

            set destocking-endangered-nomads destocking-endangered-nomads + amount-to-destock
          ]

          let herd-sum-endangered-nomads sum [livestock] of endangered-nomads ; sum up animals of endangered nomads after destocking
          set biomass-available-for-large-herds biomass-available-for-large-herds - herd-sum-endangered-nomads * intake ; deduct biomass needed for endangered-nomads
          set sum-livestock sum-livestock - herd-sum-endangered-nomads - destocking-endangered-nomads

          if sum-livestock > 0 [ set destock-percentage min ( list (( biomass-available-for-large-herds / intake ) / sum-livestock ) 1 )]

          set endangered-nomads nomads with [small-herd = false and destock-percentage * livestock < mobility-threshold]

        ] ; when leaving this while-loop either all agents have destocked to mobility threshold or the remaining ones with large herds can destock sufficiently to feed the rest

        ; large herds destock if there are still some left
        ask nomads with [ small-herd = false ]
        [
          let amount-to-destock (1 - destock-percentage) * livestock
          set livestock livestock - amount-to-destock
          if livestock <= mobility-threshold [ set small-herd true ]

          set biomass-available-for-large-herds biomass-available-for-large-herds - livestock * intake ; deduct biomass needed for each surviving animals
          set biomass-available-for-large-herds precision biomass-available-for-large-herds 8
        ]
      ] ; at this point, either large herds could be destocked sufficiently or there are only small herds left (and they still need to be destocked further) (in the latter case biomass-available-on-central-patch is < 0)


      if biomass-available-for-large-herds < 0 ;if feeding max. 5 animals of each nomad would still exceed capacity
        [
          set sum-livestock sum [ livestock ] of nomads

          ; calculate by how much herds still have to be destocked
          let capacity biomass-available-on-central-patch / intake
          let total-amount-to-destock sum-livestock - capacity
          set destock-percentage total-amount-to-destock / sum-livestock

          ; destock in equal shares
          ask nomads [
            let amount-to-destock destock-percentage * livestock
            set livestock livestock - amount-to-destock
            if livestock <= mobility-threshold [ set small-herd true ]
          ]
        ]

    ] ;end destock-percentage < 1

    let sum-livestock-new sum [livestock] of nomads
    set destock-central sum-livestock-old - sum-livestock-new
  ]
end


; have sedentary agents destock in equal shares during dry seasons
to destock-sedentary-agents
  with-local-randomness [
    if ( season = 1 or season = 3 ) [ ;=dry seasons

      if any? nomads with [small-herd = true] [; check if there are any sedentary herds

        let sedentary-nomads nomads with [small-herd = true] ; create agentset of sedentary nomads

                                                             ; determine how much biomass is available on the central patch
        let biomass-available-on-central-patch [ item season green-biomass-seasons + item season reserve-biomass-seasons ] of patch 0 0

        ; determine the number of livestock of sedentary nomads
        let small-herd-sum sum [ livestock ] of sedentary-nomads
        if small-herd-sum  <= 0 [ stop ] ; to avoid runtime errors

        let central-patch-capacity biomass-available-on-central-patch / intake

        if central-patch-capacity < small-herd-sum [
          let destock-percentage min ( list (( biomass-available-on-central-patch / intake ) / small-herd-sum ) 1 )
          ask sedentary-nomads [
            let amount-to-destock (1 - destock-percentage) * livestock
            set livestock livestock - amount-to-destock
            if livestock <= mobility-threshold [ set small-herd true ]
          ]
        ]
      ]
    ]
  ]
end


; calculate for how many animals green biomass is sufficient, remove the animals that are too much
to destock [ current-available-biomass ]
  let amount-to-destock precision ( ((intake * livestock) - current-available-biomass ) / intake ) 8
  set livestock livestock - amount-to-destock
  if livestock <= mobility-threshold [ set small-herd true ]

  if livestock <= 0.1
  [
    print ( word "year " ticks ": " who " no animals, season " season " central green " [ green-biomass ] of patch 0 0 " central green-over " [ green-biomass-over ] of patch 0 0
      " green " [ green-biomass ] of patch-here " green-over " [ green-biomass-over ] of patch-here " " [ pasture-type ] of patch-here)
  ]
end


to move
  ifelse ( season = 0 or season = 2 )
  [ ; nomads return to the central patch in every rain season
    move-to one-of patches with [ pasture-type = "central" ]
  ]
  [ ;nomads have to leave central patch in every dry season
    move-to max-one-of patches with [ pasture-type = "permanent" ] [ item season green-biomass-seasons ]
  ]
end


; cattle reproduction for every year
to-report reproduce-livestock [ livestock-old ]
  let livestock-new (1 + livestock-growth-rate) * livestock-old
  report livestock-new
end


to feed [ current-available-green-biomass current-available-reserve-biomass ]
  ifelse ( current-available-green-biomass <= intake * livestock )
  [
    ;; all green-biomass is consumed, check if reserve biomass is needed too
    ifelse ( current-available-green-biomass + current-available-reserve-biomass <= intake * livestock )
    [
      ;; green biomass and reserve biomass are consumed fully
      destock current-available-green-biomass + current-available-reserve-biomass
      ;; adjust green-biomass-over and reserve-biomass-over
      set green-biomass-over 0
      set reserve-biomass-over 0 ;reserve-biomass-over - current-available-reserve-biomass
    ]
    [
      ;; all green biomass is consumed, but reserve biomass is not needed or only partly
      let current-reserve-biomass-needed ( intake * livestock - current-available-green-biomass )
      destock current-available-green-biomass + current-reserve-biomass-needed
      ;; adjust green-biomass-over and reserve-biomass-over
      set green-biomass-over 0
      set reserve-biomass-over current-available-reserve-biomass - current-reserve-biomass-needed
    ]
  ]
  [
    ;; only green biomass is needed
    set green-biomass-over current-available-green-biomass - (livestock * intake)
  ]

  set green-biomass-seasons replace-item season green-biomass-seasons green-biomass-over
  set reserve-biomass-seasons replace-item season reserve-biomass-seasons reserve-biomass-over
  set entire-livestock fput (mean [livestock] of nomads) entire-livestock ; calculates the mean value for the livestock during the entire simulation
end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; PLOTTING AND EVALUATION PROCEDURES ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to do-plot
  with-local-randomness [
    ; graph for destocking in each season
    set-current-plot "Destocking"
    set-current-plot-pen "Remote" plot destock-remote
    set-current-plot-pen "Central" plot destock-central
    set-current-plot-pen "Insurance" plot destock-insurance
    ; graph for average number + standard deviation of livestock of all nomads
    set-current-plot "Livestock"
    set-current-plot-pen "Avg.Livestock" plot ifelse-value ( count nomads > 0 ) [ mean [livestock] of nomads ] [ 0 ]
    set-current-plot-pen "livestock+sd" plot ifelse-value ( count nomads > 0 ) [ ( mean [livestock] of nomads + ifelse-value ( count nomads > 1 ) [ standard-deviation [livestock] of nomads ] [ 0 ] ) ] [ 0 ]
    set-current-plot-pen "livestock-sd" plot ifelse-value ( count nomads > 0 ) [ ( mean [livestock] of nomads - ifelse-value ( count nomads > 1 ) [ standard-deviation [livestock] of nomads ] [ 0 ] ) ] [ 0 ]
    ; graph for average rainfall + standard deviation on all pastures
    set-current-plot "rainfall"
    set-current-plot-pen "Avg.Rain" plot mean [rain] of patches with [pasture = true]
    set-current-plot-pen "threshold" plot 100 ; shows line for a rain threshold of 100 mm/a
    set-current-plot-pen "rain-std" plot ( mean [rain] of patches with [pasture = true] - standard-deviation [rain] of patches with [pasture = true] )
    set-current-plot-pen "rain+std" plot ( mean [rain] of patches with [pasture = true] + standard-deviation [rain] of patches with [pasture = true] )
    ; graph for livestockm sum across all households
    set-current-plot "Livestock Sum"
    set-current-plot-pen "livestock-sum" plot sum [livestock] of turtles
    ; graph for number of surviving households
    set-current-plot "Surviving Households"
    set-current-plot-pen "surviving" plot count turtles
    ; graph for average reserve biomass per patch type
    set-current-plot "Reserve biomass per patch types"
    set-current-plot-pen "central" plot ( mean [ reserve-biomass ] of patches with [ pasture-type = "central" ] /
      ( initial-number-permanent-patches ) )
    set-current-plot-pen "permanent" plot mean [ reserve-biomass ] of patches with [ pasture-type = "permanent" ]
    set-current-plot-pen "permanent+SD" plot ( mean [ reserve-biomass ] of patches with [ pasture-type = "permanent" ] + standard-deviation [ reserve-biomass ] of patches with [ pasture-type = "permanent" ] )
    set-current-plot-pen "permanent-SD" plot ( mean [ reserve-biomass ] of patches with [ pasture-type = "permanent" ] - standard-deviation [ reserve-biomass ] of patches with [ pasture-type = "permanent" ] )
    ; graph for average green biomass per patch type
    set-current-plot "Green biomass per patch types"
    set-current-plot-pen "central" plot ( mean [ green-biomass ] of patches with [ pasture-type = "central" ] /
      ( initial-number-permanent-patches ) )
    set-current-plot-pen "permanent" plot mean [ green-biomass ] of patches with [ pasture-type = "permanent" ]
    set-current-plot-pen "central-over" plot ( mean [ green-biomass-over ] of patches with [ pasture-type = "central" ] /
      ( initial-number-permanent-patches ) )
    set-current-plot-pen "permanent-over" plot mean [ green-biomass-over ] of patches with [ pasture-type = "permanent" ]
    set-current-plot "Individual-Livestock" plot-individual-livestock
    set-current-plot "green biomass over - central"
;    set-current-plot-pen "over" plot ifelse-value ( count nomads > 0 ) [ ln ( 1 + mean [ item season green-biomass-seasons ] of patches with [ pasture-type = "central" ] / (intake * mean [livestock] of nomads)) ] [ 0 ]
    set-current-plot-pen "over" plot ifelse-value ( count nomads > 0 ) [ min (list (mean [ item season green-biomass-seasons ] of patches with [ pasture-type = "central" ] / (intake * mean [livestock] of nomads)) 5) ] [ 0 ]
    set-current-plot-pen "pen-1" plot 1

  ]
end


to plot-individual-livestock
  with-local-randomness [
    if count nomads > 0
    [
      clear-plot
      set-plot-x-range 0 count nomads

      let x 0
      foreach sort-on [ livestock ] nomads
      [
        set-current-plot-pen "livestock"
        ifelse ([ livestock ] of ? <= 5)
          [ set-plot-pen-color 15 ]
          [ set-plot-pen-color 105 ]
        plotxy x [ livestock ] of ?
        set x x + 1
      ]
    ]
  ]
end


to plot-lorenz
  with-local-randomness [
    if count nomads > 0
    [
      set-current-plot "Lorenz Curve"

      clear-plot
      set-plot-x-range 0 initial-number-nomads ;count households
      set-plot-y-range 0 1

      set-current-plot-pen "lorenz"
      plotxy 0 0
      let x 1
      let sum-livestock sum [ livestock ] of nomads
      let part-sum-livestock 0
      let dead-nomads initial-number-nomads - count nomads

      repeat dead-nomads
      [
        plotxy x 0
        set x x + 1
      ]

      foreach sort-on [ livestock ] nomads
      [
        carefully
        [
          plotxy x ( ( part-sum-livestock + [ livestock ] of ? ) / sum-livestock )
        ]
        [
          plotxy x 0
        ]
        set x x + 1
        set part-sum-livestock part-sum-livestock + [ livestock ] of ?
      ]
    ]
  ]
end


to-report gini-coef
  ifelse ( count nomads > 0 )
    [
      let gini 0

      with-local-randomness [

        let x-part 1 / initial-number-nomads;count nomads
        let distribution-area 0
        let sum-livestock sum [ livestock ] of nomads
        let part-area-livestock 0

        foreach sort-on [ livestock ] nomads
        [
          set part-area-livestock part-area-livestock + ( [ livestock ] of ? / sum-livestock )
          let part-area ( part-area-livestock - ( [ livestock ] of ? / ( 2 * sum-livestock )  ) ) * x-part
          set distribution-area distribution-area + part-area
        ]

        set gini 1 - 2 * distribution-area
      ]

      report gini
    ]
    [
      report 0
    ]
end


to-report gini-coef-surviving
    ifelse ( count nomads > 0 )
    [
      let gini 0

      with-local-randomness [

        let x-part 1 / count nomads
        let distribution-area 0
        let sum-livestock sum [ livestock ] of nomads
        let part-area-livestock 0

        foreach sort-on [ livestock ] nomads
        [
          set part-area-livestock part-area-livestock + ( [ livestock ] of ? / sum-livestock )
          let part-area ( part-area-livestock - ( [ livestock ] of ? / ( 2 * sum-livestock )  ) ) * x-part
          set distribution-area distribution-area + part-area
        ]

        set gini 1 - 2 * distribution-area
      ]

      report gini
    ]
    [
      report 0
    ]
end


to setup-output-files
  with-local-randomness [

    set nomad-name-list sort nomads  ; store all agents in a list: "[(nomad 0) (nomad 1) (nomad 2)... ]"
    set patches-ordered sort-on [patch-number] patches with [pasture-type = "permanent"]

    ; file with general info
    set filename ( word "output/" behaviorspace-experiment-name "/" behaviorspace-run-number ".csv" )
    if file-exists? filename [file-delete filename]
    file-open filename
    file-print ( word "run; season.count; year; season; survHH; mean.livestock; sum.livestock; sd.livestock; central.reserve; perm.reserve; central.green; perm.green; central.green.over; perm.green.over; mean.rain; sd.rain; mean.bank; sd.bank" )
    file-print ( word behaviorspace-run-number "; " season-count "; "ticks"; "season"; " count nomads "; " mean [ livestock ] of nomads "; " sum [ livestock ] of nomads "; " ifelse-value ( count nomads > 1 ) [ standard-deviation [ livestock ] of nomads ] [ 0 ] "; " mean [ reserve-biomass ] of patches with [ pasture-type = "central" ] "; " mean [ reserve-biomass ] of patches with [ pasture-type = "permanent" ] "; " mean [ green-biomass ] of patches with [ pasture-type = "central" ] "; " mean [ green-biomass ] of patches with [ pasture-type = "permanent" ] "; " mean [ green-biomass-over ] of patches with [ pasture-type = "central" ] "; " mean [ green-biomass-over ] of patches with [ pasture-type = "permanent" ] "; " mean [rain] of patches with [pasture = true] "; " standard-deviation [rain] of patches with [pasture = true] "; " mean [savings] of nomads "; " ifelse-value ( count nomads > 1 ) [ standard-deviation [savings] of nomads ] [ 0 ] )
    file-close

    ; file with agent info
    set filename-agents ( word "output/" behaviorspace-experiment-name "/" behaviorspace-run-number "-agents.csv" )
    if file-exists? filename-agents [file-delete filename-agents]
    file-open filename-agents

    let livestock-name-list n-values initial-number-nomads [(word "livestock" ?)] ; create column headers for livestock values of all agents: "livestock0" "livestock1" ...
    let bank-name-list n-values initial-number-nomads [(word "bank" ?)] ; create column headers for savings values of all agents: "bank0" "bank1" ...

    let herd-list [] ; create a whitespace-separated list of livestock values of all agents
    foreach nomad-name-list [ set herd-list lput
      ifelse-value ( ? != nobody )
      [ [ livestock ] of ? ] ; if agent alive, store herd-size in list
      [ "NA" ] herd-list        ; if agent dead, store value 0
    ]

    let bank-list [] ; create a whitespace-separated list of savings values of all agents
    foreach nomad-name-list [ set bank-list lput
      ifelse-value ( ? != nobody )
      [ [ savings ] of ? ] ; if agent alive, store savings in list
      [ "NA" ] bank-list        ; if agent dead, store "NA"
    ]

    file-print ( word "run season.count year season " but-first but-last (word livestock-name-list) " " but-first but-last (word bank-name-list) )
    file-print ( word behaviorspace-run-number " " season-count " "ticks" "season" " but-first but-last (word herd-list) " " but-first but-last (word bank-list) )
    file-close

    ; file with patch info
    set filename-patches ( word "output/" behaviorspace-experiment-name "/" behaviorspace-run-number "-patches.csv" )
    if file-exists? filename-patches [file-delete filename-patches]
    file-open filename-patches

    let ResBio-names n-values initial-number-permanent-patches [(word "RemResBio" ?)] ; create column headers for reserve biomass values of all patches: "ResBio0" "ResBio1" ...
    let GrBio-names n-values initial-number-permanent-patches [(word "RemGreenBio" ?)] ; create column headers for reserve biomass values of all patches: "GreenBio0" "GreenBio1" ...
    let GrBioOver-names n-values initial-number-permanent-patches [(word "RemGreenBioOver" ?)] ; create column headers for reserve biomass values of all patches: "GreenBioOver0" "GreenBioOver1" ...
    let patch-names (sentence ResBio-names GrBio-names GrBioOver-names)

    let patch-list [] ; create a whitespace-separated list of livestock values of all agents
    foreach patches-ordered [ set patch-list lput [reserve-biomass] of ? patch-list ]
    foreach patches-ordered [ set patch-list lput [green-biomass] of ? patch-list ]
    foreach patches-ordered [ set patch-list lput [green-biomass-over] of ? patch-list ]
    file-print ( word "run season.count year season CentrResBio CentrGreenBio CentrGreenBioOver " but-first but-last (word patch-names) )
    file-print ( word behaviorspace-run-number " " season-count " "ticks" "season" "(word [reserve-biomass] of patch 0 0 " " [green-biomass] of patch 0 0 " " [green-biomass-over] of patch 0 0 " ") but-first but-last (word patch-list) )
    file-close
  ]
end


to do-write-output
  with-local-randomness [
    ; file with general info
    file-open filename
    file-print ( word behaviorspace-run-number "; " season-count "; "ticks "; "season"; " count nomads "; " mean [ livestock ] of nomads "; " sum [ livestock ] of nomads "; " ifelse-value ( count nomads > 1 ) [ standard-deviation [ livestock ] of nomads ] [ 0 ] "; " mean [ reserve-biomass ] of patches with [ pasture-type = "central" ] "; " mean [ reserve-biomass ] of patches with [ pasture-type = "permanent" ] "; " mean [ green-biomass ] of patches with [ pasture-type = "central" ] "; " mean [ green-biomass ] of patches with [ pasture-type = "permanent" ] "; " mean [ green-biomass-over ] of patches with [ pasture-type = "central" ] "; " mean [ green-biomass-over ] of patches with [ pasture-type = "permanent" ] "; " mean [rain] of patches with [pasture = true] "; " standard-deviation [rain] of patches with [pasture = true] "; " mean [savings] of nomads "; " ifelse-value ( count nomads > 1 ) [ standard-deviation [savings] of nomads ] [ 0 ] )
    file-close

    ; file with agent info
    file-open filename-agents
    let herd-list []
    foreach nomad-name-list [ set herd-list lput
      ifelse-value ( ? != nobody )
      [ [ livestock ] of ? ] ; if agent alive, store herd-size in list
      [ "NA" ] herd-list        ; if agent dead, store value 0
    ]

    let bank-list [] ; create a whitespace-separated list of savings values of all agents
    foreach nomad-name-list [ set bank-list lput
      ifelse-value ( ? != nobody )
      [ [ savings ] of ? ] ; if agent alive, store savings in list
      [ "NA" ] bank-list        ; if agent dead, store "NA"
    ]

    file-print ( word behaviorspace-run-number " " season-count " "ticks" "season" " but-first but-last (word herd-list) " " but-first but-last (word bank-list) )
    file-close

    ; file with patch info
    file-open filename-patches
    let patch-list [] ; create a whitespace-separated list of livestock values of all agents
    foreach patches-ordered [ set patch-list lput [reserve-biomass] of ? patch-list ]
    foreach patches-ordered [ set patch-list lput [green-biomass] of ? patch-list ]
    foreach patches-ordered [ set patch-list lput [green-biomass-over] of ? patch-list ]
    file-print ( word behaviorspace-run-number " " season-count " "ticks" "season" "(word [reserve-biomass] of patch 0 0 " " [green-biomass] of patch 0 0 " " [green-biomass-over] of patch 0 0 " ") but-first but-last (word patch-list) )
    file-close
  ]
end


to create-movement-list
  ; create a second-order nested list with the following information (from innermost to outmost):
  ; - list of all nomads in random order
  ; - one of the above list for each season
  ; - one of the above nested list for each year
  set movement-list []
  with-local-randomness [
    repeat (number-timesteps + 1) [set movement-list lput report-yearly-movement movement-list]
  ]
end


to-report report-yearly-movement
  let year-list (list [self] of nomads [self] of nomads [self] of nomads [self] of nomads) ;concatenate four lists of shuffled agents
  report year-list
end


to create-lists
  set livestock-sum-list []
  set central-reserve-biomass-list []
  set mean-remote-reserve-biomass-list []
end


to update-lists
  if ticks >= ins-start [
    with-local-randomness[
      set livestock-sum-list lput ( sum [ livestock ] of nomads ) livestock-sum-list
      set central-reserve-biomass-list lput ( mean [ reserve-biomass ] of patches with [ pasture-type = "central" ] ) central-reserve-biomass-list
      set mean-remote-reserve-biomass-list lput ( mean [ reserve-biomass ] of patches with [ pasture-type = "permanent" ] ) mean-remote-reserve-biomass-list
    ]
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
305
15
568
299
12
12
10.15
1
10
1
1
1
0
0
0
1
-12
12
-12
12
0
0
1
ticks (years)
30.0

PLOT
1365
10
1860
244
Destocking
Seasons
Heads of cattle
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Remote" 1.0 0 -12087248 true "" ""
"Central" 1.0 0 -2674135 true "" ""
"Insurance" 1.0 0 -13345367 true "" ""

BUTTON
45
20
108
53
NIL
setup
NIL
1
T
OBSERVER
NIL
P
NIL
NIL
1

BUTTON
47
63
110
96
go
go
T
1
T
OBSERVER
NIL
G
NIL
NIL
1

PLOT
750
135
1360
255
Livestock
Seasons
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"Avg.Livestock" 1.0 0 -16777216 true "" ""
"livestock+sd" 1.0 0 -7500403 true "" ""
"livestock-sd" 1.0 0 -7500403 true "" ""

MONITOR
575
265
740
310
Avg. Green Biomass
mean [green-biomass] of patches
0
1
11

MONITOR
575
15
747
60
current mean livestock
mean [livestock] of turtles
4
1
11

BUTTON
48
108
111
141
step
go
NIL
1
T
OBSERVER
NIL
S
NIL
NIL
1

SLIDER
15
190
155
223
initial-number-nomads
initial-number-nomads
1
100
10
1
1
NIL
HORIZONTAL

PLOT
750
10
1360
130
Rainfall
Seasons
mm/a
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"Avg.Rain" 1.0 0 -16777216 true "" ""
"threshold" 1.0 0 -2674135 true "" ""
"rain-std" 1.0 0 -7500403 true "" ""
"rain+std" 1.0 0 -7500403 true "" ""

MONITOR
574
215
744
260
Avg. Reserve Biomass
mean [reserve-biomass] of patches with [pasture = true]
0
1
11

SLIDER
15
320
155
353
rain-std
rain-std
0
300
80
10
1
mm/a
HORIZONTAL

SLIDER
15
370
155
403
rain-mean
rain-mean
0
400
180
10
1
mm/a
HORIZONTAL

SLIDER
15
230
265
263
initial-number-permanent-patches
initial-number-permanent-patches
0
100
20
1
1
pastures
HORIZONTAL

MONITOR
574
315
739
360
Avg. Green Biomass Over
mean [green-biomass-over] of patches
0
1
11

PLOT
1366
251
1711
401
Individual-Livestock
Months
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"livestock" 1.0 1 -13345367 true "" ""

MONITOR
575
65
745
110
mean livestock (entire simulation)
mean entire-livestock
4
1
11

MONITOR
310
305
395
350
Avg. Rain
mean-rain
0
1
11

SLIDER
15
148
155
181
number-timesteps
number-timesteps
0
2500
1000
100
1
NIL
HORIZONTAL

TEXTBOX
173
415
323
441
reads in rainfall data from an external file
11
0.0
1

TEXTBOX
165
150
284
178
maxmimum number of ticks per run
11
0.0
1

MONITOR
575
165
745
210
Nomads with Livestock
count nomads with [livestock > 0]
0
1
11

SLIDER
15
480
155
513
gr1
gr1
0
1
0.5
0.05
1
NIL
HORIZONTAL

TEXTBOX
20
515
110
560
green biomass\n0.5 = Standard\n0 = high / 1 = low
11
0.0
1

TEXTBOX
160
385
310
403
Standard = 180
11
0.0
1

TEXTBOX
164
338
314
356
Standard = 80
11
0.0
1

MONITOR
575
115
745
160
Current sum livestock
sum [ livestock ] of turtles
17
1
11

PLOT
750
260
1360
380
Livestock Sum
Seasons
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"livestock-sum" 1.0 0 -16777216 true "" ""

PLOT
750
385
1360
505
Surviving Households
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"surviving" 1.0 0 -16777216 true "" ""

PLOT
750
510
1360
630
Reserve biomass per patch types
NIL
NIL
0.0
10.0
0.0
150000.0
true
false
"" ""
PENS
"central" 1.0 0 -5298144 true "" ""
"permanent" 1.0 0 -13840069 true "" ""
"temporary" 1.0 0 -1184463 true "" ""
"permanent+SD" 1.0 0 -5509967 true "" ""
"permanent-SD" 1.0 0 -5509967 true "" ""

PLOT
750
635
1360
755
Green biomass per patch types
NIL
NIL
0.0
231.0
0.0
89200.0
true
false
"" ""
PENS
"central" 1.0 0 -8053223 true "" ""
"permanent" 1.0 0 -13840069 true "" ""
"temporary" 1.0 0 -1184463 true "" ""
"central-over" 1.0 0 -2674135 true "" ""
"permanent-over" 1.0 0 -8330359 true "" ""
"temporary-over" 1.0 0 -723837 true "" ""

SLIDER
160
480
300
513
gr2
gr2
0
1
0.1
0.05
1
NIL
HORIZONTAL

TEXTBOX
20
460
105
478
grazing pressure
11
0.0
1

TEXTBOX
165
515
255
556
reserve biomass\n0.1 = standard\n0 = low / 1 = high
11
0.0
1

PLOT
1365
410
1710
580
Lorenz Curve
NIL
NIL
0.0
10.0
0.0
10.0
false
false
"" ""
PENS
"lorenz" 1.0 0 -16777216 true "" "plot-lorenz"
"pen-1" 1.0 0 -7500403 true "" "plotxy 0 0\nplotxy initial-number-nomads 1"

MONITOR
1365
585
1460
630
Gini Coefficient
gini-coef
4
1
11

MONITOR
1465
585
1623
630
Gini Coefficient (surviving)
gini-coef-surviving
4
1
11

PLOT
1365
635
1710
760
green biomass over - central
NIL
NIL
0.0
10.0
0.0
5.0
true
false
"" ""
PENS
"over" 1.0 0 -16777216 true "" ""
"pen-1" 1.0 0 -7500403 true "" ""

SWITCH
20
640
127
673
insurance
insurance
0
1
-1000

INPUTBOX
320
640
390
700
strike-level
100
1
0
Number

MONITOR
405
645
480
690
NIL
Prob-payout
17
1
11

TEXTBOX
164
197
274
215
Standard = 10
11
0.0
1

INPUTBOX
225
640
305
700
ins-start
15
1
0
Number

TEXTBOX
324
703
373
721
Std = 100\n
11
0.0
1

TEXTBOX
222
704
322
759
Time when agents start buying insurance\nStd = 15
11
0.0
1

INPUTBOX
140
640
210
700
max-ins-sum
55
1
0
Number

SWITCH
165
25
292
58
write-output?
write-output?
1
1
-1000

SLIDER
15
275
155
308
lambda
lambda
0
5
2
.05
1
NIL
HORIZONTAL

TEXTBOX
164
272
304
328
maximum proportion of green biomass to brown biomass\nstandard = 2
11
0.0
1

CHOOSER
15
410
167
455
rainfall-scenario
rainfall-scenario
"rain6yrsAsc.txt" "rain6yrsDesc.txt" "rain6yrsNegAC.txt" "laisamisdata.txt" "random" "constant"
0

SLIDER
325
370
497
403
Rmax-value
Rmax-value
50000
300000
150000
10000
1
NIL
HORIZONTAL

SLIDER
325
410
497
443
rue
rue
0
.01
0.0020
.0001
1
NIL
HORIZONTAL

SLIDER
325
450
497
483
w
w
0
1
0.8
.05
1
NIL
HORIZONTAL

SLIDER
325
490
495
523
reserve-biomass-mortality
reserve-biomass-mortality
0
.3
0.05
.01
1
NIL
HORIZONTAL

SLIDER
325
530
495
563
green-biomass-mortality
green-biomass-mortality
0
1
0.3
0.05
1
NIL
HORIZONTAL

SLIDER
325
570
495
603
livestock-growth-rate
livestock-growth-rate
0
.5
0.085
.005
1
NIL
HORIZONTAL

SLIDER
15
565
185
598
annual-intake
annual-intake
3000
6000
4500
250
1
NIL
HORIZONTAL

TEXTBOX
505
370
655
396
carrying-capacity\nstandard = 150 000
11
0.0
1

TEXTBOX
505
410
655
436
rain-use efficiency\nstandard = 0.002
11
0.0
1

TEXTBOX
505
450
655
476
contribution of G to R growth\nstandard = 0.8
11
0.0
1

TEXTBOX
505
495
655
513
standard = 0.05
11
0.0
1

TEXTBOX
505
535
655
553
standard = 0.3
11
0.0
1

TEXTBOX
505
575
655
593
standard = 0.085
11
0.0
1

TEXTBOX
195
565
345
591
annual forage intake\nstandard = 4500
11
0.0
1

MONITOR
410
305
520
358
ticks (yr)
ticks
1
1
13

TEXTBOX
20
620
170
638
Insurance
13
0.0
1

TEXTBOX
490
645
640
686
Probability that insurance pays out (= likelihood of drought events)
11
0.0
1

TEXTBOX
175
65
325
83
export output to files?
11
0.0
1

@#$#@#$#@
## WHAT IS IT?

This agentbased model simulates mobile pastoralism, making use of ecological data from Northern Kenya to incorporate the case example "Borana pastoralists in Kenya". The main components of the model are the agents (nomads) and their livestock. The spatital structure consists of different kind of patches symbolizing pastures with several attributes. The model is based on DREßLER et al. 2012 but contains characteristics of the case study like different seasons and a differentiation of dry season pastures.

This model was implemented by Mads Steinicke as part of the thesis "Weidenutzungsstrategien der Borana in Kenia, unter Berücksichtigung verschiedener Wandelprozesse - Eine Analyse mittels agentenbasierter Modellierung", in order to earn the degree Bachelor of Science.


## HOW IT WORKS

### Patches

Setting up the model three different types of patches are created. The black spaces do not have a meaning and are considered empty.  There is the single lime coloured central patch, which holds, based on the central-biomass-factor, a multiple amount of reserve biomass and reserve biomass capacity of the other pastures. In addition there are two different types of remote patches: permanent (green) and temporary (yellow).  Both hold 50,000 kg of initial reserve biomass and a capacity of 150,000 kg and are classified as dry season patches. Permanent patches are always accessible while temporary patches have a rain threshold. This means that they carry no available water if the rainfall is below the limit of 100 mm/a, and therefor are not accessible. During the simulation rainfall is calculated yearly with a lognormal distribution split up unequally to the different seasons:

long rain season (Apr - Jun): 50 %
long dry season (Jul - Sep): 5 %
short rain season (Oct - Dec): 35 %
short dry season (Jan - Mar): 10 %.


### Agents
When the model is setup the nomads are created equally as white manikins on the central patch (coordinates 0 0), symbolizing the main village with several waterpoints and a high amount of reserve biomass. They all start with a randomly calculated amount of livestock (sheep) between 5 and 10 animals (sheep). The nomads (and their livestock) follow a set of rules, repeated every four seasons, conducted randomly one after another in the following order:

Reproduction: livestock reproduces once at the beginning of the year during the first rain season,
Move: moving to a different patch based on the current season: to the remote patch with the most currently available biomass during dry season and back to the central patch during rain season,
Feed: feeding livestock on currently available biomass based on daily intake of 160 kg per animal per season (they might have to destock in case the entire green biomass has been consumed),
Destock: destocking the livestock after calculating for how many sheep green biomass is sufficient (simply remove the sheep that are supernumerous).


### Biomass

Biomass is split into three major parts during the simulation:

green biomass (accessible for livestock, including the remaining biomass from year t-1), reserve biomass (forms basis of green biomass, cannot be grazed in this version),
green biomass over (denoting the carry over from last year's green biomass after grazing).

The calculated green biomass is then split into four seasons, based on the mean rainfall.

#### For more detailed information on how biomass is calculated see: MARTIN et al. 2013 "How much climate change can pastoral livelihoods tolerate? Modelling rangeland use and evaluating risk"  (Appendix)



## HOW TO USE IT

### Input

The model's interface offers merely three buttons to run the simulation. At first there is the "setup-button", which establishes the world and calculates its attributes (see above). Then there are two buttons to actually start the model: "step" and "go". Clicking "step" advances the model one tick (one year respectively four seasons) instead of running the model forever by clicking the "go-button" (until it is clicked again). Underneath the buttons there are eight sliders and three switches.
The initial number of agents (nomads) and remote patches can only be set before clicking "setup" whereas the two rain parameters have to be clicked on afterwards. "Rain-std" determines the standard deviation and "rain-mean" the mean value of the rainfall during every year. The slider "grazing-harshness" changes the pressure applied on the pastures by grazing (0 defines a high value and 1 a low value). The slider "central-biomass-factor" allows to change the reserve biomass ratio of central patch and remote patches. The three rainfall varying switches are explained further down.

### Output

On the right side of the view of the two dimensional world with 41 x 41 patches are several plots and monitors to display the current biomass, livestock and rainfall data. The average amount (of all pastures) of green biomass, reserve biomass and green biomass carryover is plotted in the biggest chart called "Biomass". Next to that plot you will find three monitors displaying the current matter in kg of that line graph. Beneath that section are three other plots with proper monitors, showing current average livestock (of all nomads) and rainfall. The red line in the "Rainfall"- plot is equipollent to the threshold of temporary pastures (100 mm/a). The "Avg. Rain"- monitor shows the current rainfall in mm/a of the "Rainfall"- plot (all pastures averaged). The "Every-Livestock"- plot shows the gradient of every single nomad included in the current simulation, whereas the last monitor called "Avg. Livestock entire Simulation" displays the mean value for the amount of livestock during the complete simulation run. The monitor "Nomads with Livestock" shows how many agents still have at least on animal in the current simulation.

## THINGS TO NOTICE


In this first version of the model no reserve biomass can be grazed.
Due to a lack of real ecological data, this model is a strongly simplyfied image of the Borana range use. All parameters are taken from another stylized vegetationmodel of a semiarid system (cf. MÜLLER et al. 2007).

## THINGS TO TRY

There are two switches embedded in the interface, one for enabling droughts and one to disable "global rain". Usually "global rain" should be switched on, so that rainfall is created equally for all pastures, due to relatively small differences between the micro climates of the waterpoints in reality.
When switched on, "droughts" intersperses aridity every 20 ticks (years) and sets rainfall to 40 mm/a.
The switch "rainfall-scenario?" enables a pre set rainfall scenario based on 47 years of rainfall data from Laisamis, Marsabit (cf. TOTH 2014)

## EXTENDING THE MODEL

The model, or rather its paramters, can be adjusted to any user-defined case study about land use strategies in pastoral systems by simply changing the values of the "globals" at the beginning of the code.


## RELATED MODELS

You can find a model with similar features here:
http://ccl.northwestern.edu/netlogo/models/community/Growth_Used_in_Chapter_and_Distributed

## CREDITS AND REFERENCES

DREßLER, G., B. MÜLLER & K. FRANK. 2012. Mobility – a panacea for pastoralism? An ecological-economic modelling approach. In 2012 International Congress on Environmental Modelling and Software Managing Resources of a Limited Planet, 8. Leipzig.

MARTIN, R. B. MÜLLER, A. LINSTÄDTER & K. FRANK 2013. How much climate change can pastoral livelihoods tolerate? Modelling rangeland use and evaluating risk. Global Environmental Change-Human and Policy Dimensions, 10.

MÜLLER, B., K. FRANK & C. WISSEL 2007. Relevance of rest periods in non-equilibrium rangeland systems - A modeling analysis. Agricutural System, 92, 295-317.

TOTH, R. 2014. Unpublished work.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.2.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Ins_lambda_1000yrs" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count nomads</metric>
    <metric>mean [ livestock ] of nomads</metric>
    <metric>sum [ livestock ] of nomads</metric>
    <metric>ifelse-value ( count nomads &gt; 1 ) [ standard-deviation [ livestock ] of nomads ] [ 0 ]</metric>
    <metric>mean [ reserve-biomass ] of patches with [ pasture-type = "central" ]</metric>
    <metric>mean [ reserve-biomass ] of patches with [ pasture-type = "permanent" ]</metric>
    <metric>mean [ green-biomass ] of patches with [ pasture-type = "central" ]</metric>
    <metric>mean [ green-biomass ] of patches with [ pasture-type = "permanent" ]</metric>
    <metric>mean [ green-biomass-over ] of patches with [ pasture-type = "central" ]</metric>
    <metric>mean [ green-biomass-over ] of patches with [ pasture-type = "permanent" ]</metric>
    <metric>mean [rain] of patches with [pasture = true]</metric>
    <metric>standard-deviation [rain] of patches with [pasture = true]</metric>
    <metric>mean [ savings ] of nomads</metric>
    <metric>ifelse-value ( count nomads &gt; 1 ) [ standard-deviation [savings] of nomads ] [ 0 ]</metric>
    <enumeratedValueSet variable="insurance">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="200"/>
    <enumeratedValueSet variable="lambda">
      <value value="0.5"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ins-start">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rain-std">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-nomads">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strike-level">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gr1">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-timesteps">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ins-sum">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gr2">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rainfall-scenario">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rain-mean">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-permanent-patches">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-output?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Ins_std-params_ind-output" repetitions="1" runMetricsEveryStep="true">
    <setup>setup
show (word "starting run #" behaviorspace-run-number)</setup>
    <go>go</go>
    <metric>mean [rain] of patches with [pasture = true]</metric>
    <metric>standard-deviation [rain] of patches with [pasture = true]</metric>
    <enumeratedValueSet variable="insurance">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="lambda">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ins-start">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rain-std">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-nomads">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strike-level">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gr1">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-timesteps">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ins-sum">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gr2">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rainfall-scenario">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rain-mean">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-permanent-patches">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-output?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Shoebox_6yrs_Ins_gr1" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count nomads</metric>
    <metric>sum [ livestock ] of nomads</metric>
    <metric>ifelse-value ( count nomads &gt; 1 ) [ standard-deviation [ livestock ] of nomads ] [ 0 ]</metric>
    <metric>mean [ reserve-biomass ] of patches with [ pasture-type = "central" ]</metric>
    <metric>mean [ reserve-biomass ] of patches with [ pasture-type = "permanent" ]</metric>
    <metric>ifelse-value ( count patches with [ pasture-type = "permanent" ] &gt; 1 ) [ standard-deviation [ reserve-biomass ] of patches with [ pasture-type = "permanent" ] ] [ 0 ]</metric>
    <metric>mean [rain] of patches with [pasture = true]</metric>
    <enumeratedValueSet variable="random-seed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rue">
      <value value="0.0020"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rmax-value">
      <value value="150000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reserve-biomass-mortality">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lambda">
      <value value="2"/>
    </enumeratedValueSet>
    <steppedValueSet variable="gr1" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="rain-mean">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ins-start">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="insurance">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-permanent-patches">
      <value value="20"/>
    </enumeratedValueSet>
    <steppedValueSet variable="max-ins-sum" first="0" step="1" last="55"/>
    <enumeratedValueSet variable="green-biomass-mortality">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-timesteps">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-nomads">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gr2">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rainfall-scenario">
      <value value="&quot;rain6yrsDesc.txt&quot;"/>
      <value value="&quot;rain6yrsAsc.txt&quot;"/>
      <value value="&quot;rain6yrsNegAC.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="annual-intake">
      <value value="4500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strike-level">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rain-std">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="livestock-growth-rate">
      <value value="0.085"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Shoebox_RandRain_Ins_gr1" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count nomads</metric>
    <metric>sum [ livestock ] of nomads</metric>
    <metric>ifelse-value ( count nomads &gt; 1 ) [ standard-deviation [ livestock ] of nomads ] [ 0 ]</metric>
    <metric>mean [ reserve-biomass ] of patches with [ pasture-type = "central" ]</metric>
    <metric>mean [ reserve-biomass ] of patches with [ pasture-type = "permanent" ]</metric>
    <metric>ifelse-value ( count patches with [ pasture-type = "permanent" ] &gt; 1 ) [ standard-deviation [ reserve-biomass ] of patches with [ pasture-type = "permanent" ] ] [ 0 ]</metric>
    <metric>mean [rain] of patches with [pasture = true]</metric>
    <enumeratedValueSet variable="random-seed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rue">
      <value value="0.0020"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rmax-value">
      <value value="150000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reserve-biomass-mortality">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lambda">
      <value value="2"/>
    </enumeratedValueSet>
    <steppedValueSet variable="gr1" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="rain-mean">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ins-start">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="insurance">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-permanent-patches">
      <value value="20"/>
    </enumeratedValueSet>
    <steppedValueSet variable="max-ins-sum" first="0" step="1" last="55"/>
    <enumeratedValueSet variable="green-biomass-mortality">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-timesteps">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-nomads">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gr2">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rainfall-scenario">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="annual-intake">
      <value value="4500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strike-level">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rain-std">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="drought-frequency">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="livestock-growth-rate">
      <value value="0.085"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Ins40_std-params_ind-output" repetitions="1" runMetricsEveryStep="true">
    <setup>setup
show (word "starting run #" behaviorspace-run-number)</setup>
    <go>go</go>
    <metric>mean [rain] of patches with [pasture = true]</metric>
    <metric>standard-deviation [rain] of patches with [pasture = true]</metric>
    <enumeratedValueSet variable="insurance">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="lambda">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ins-start">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rain-std">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-nomads">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strike-level">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gr1">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-timesteps">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ins-sum">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gr2">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rainfall-scenario">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rain-mean">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-permanent-patches">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-output?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
1
@#$#@#$#@
